import 'dart:convert';
import 'dart:developer';
import 'dart:io';


import 'package:http/http.dart' as http;
import 'package:soliq_id/soliq_id.dart';

import '../../utils/exceptions.dart';
import '../model/request/account_info_request.dart';
import '../model/request/compare_face_request.dart';
import '../model/request/create_session_request.dart';
import '../model/request/process_request.dart';
import '../model/response/account_info_response.dart';
import '../model/response/create_session_response.dart';
import '../model/response/process_response.dart';




class SoliqIdApi  {
  final String baseUrl = "https://api.myfaceid.uz";


  headersCustom() async {
    var token = await pref!.guidToken;
    return {
      HttpHeaders.authorizationHeader: 'Bearer $token',
      HttpHeaders.contentTypeHeader: 'application/json; charset=UTF-8',
      // "time": control.time,
    };
  }




  Future<AccountInfoResponse> getAccountInfo( AccountInfoRequest request) async {
    var responseJson;
    final url =
    Uri.parse('$baseUrl/soliq-id/get-account-info');

    try {
      final response = await http
          .post(url,
          body: jsonEncode(request.toJson()), headers: await headersCustom());

      log("$response", );
      log("$request", );


      responseJson = AccountInfoResponse.fromJson(json.decode(utf8.decode(response.bodyBytes)));
      return responseJson;
    } on FetchDataException {
      throw FetchDataException("No Internet connection");
    }
    return responseJson;
  }



  Future<CreateSessionResponse> createSession(CreateSessionRequest request) async {
    var responseJson;
    final url =
    Uri.parse('$baseUrl/soliq-id/create-session');

    try {
      final response = await http
          .post(url,
          body: jsonEncode(request.toJson()), headers: await headersCustom());

      log("$response", );
      log("$request", );


      responseJson = CreateSessionResponse.fromJson(json.decode(utf8.decode(response.bodyBytes)));
    return responseJson;
    } on FetchDataException {
      throw FetchDataException("No Internet connection");
    }
    return responseJson;
  }


  Future<ProcessResponse> logsApi(ProcesseRequest request) async {
    var responseJson;
    final url =
    Uri.parse('$baseUrl/soliq-id/set-process');

    try {
      final response = await http
          .post(url,
          body: jsonEncode(request.toJson()), headers: await headersCustom());

      log("$response", );
      log("$request", );


      responseJson = ProcessResponse.fromJson(json.decode(utf8.decode(response.bodyBytes)));
      return responseJson;
    } on FetchDataException {
      throw FetchDataException("No Internet connection");
    }
    return responseJson;
  }

  Future<ProcessResponse> faceCompare( CompareFaceRequest request) async {
    var responseJson;
    final url =
    Uri.parse('$baseUrl/soliq-id/compare-face');

    try {
      final response = await http
          .post(url,
          body: jsonEncode(request.toJson()), headers: await headersCustom());

      log("$response", );
      log("$request", );


      responseJson = ProcessResponse.fromJson(json.decode(utf8.decode(response.bodyBytes)));
      return responseJson;
    } on FetchDataException {
      throw FetchDataException("No Internet connection");
    }
    return responseJson;
  }




}

